Contributing and issue reporting
================================

You can contribute and report issues in the usual way as
`documented by GitHub <https://guides.github.com/activities/contributing-to-open-source/>`_.

If you found a security vulnerability that might put users at risk please send
your report/patch to ypid@riseup.net. Please consider using OpenPGP to encrypt
your email.
